@@ -1,11 +1,10 @@
 from copy import deepcopy
 import os
-import six
 
 from databuild.compat import _open
 from databuild.facets import sum_facets
 from databuild.loader import load_classpath, load_classpath_whitelist
-from databuild.utils import render_string
+from databuild.utils import render_string, recursive_render
 
 
 runtime_operations = {}
@@ -78,9 +77,10 @@ class Operator(object):
             _description = render_string(description, context)
             print(_description)
 
+        kwargs = deepcopy(kwargs)
+
         for k, v in kwargs.items():
-            if k != 'description' and isinstance(v, six.string_types):
-                kwargs[k] = render_string(v, context)
+            kwargs[k] = recursive_render(v, context)
 
         fn(context, **kwargs)
 
